@@ -435,7 +435,7 @@ impl VsMgmt for MapxRawVs {
     #[inline(always)]
     fn version_exists(&self, version_name: VersionName) -> bool {
         self.inner
-            .get_version_id(BranchName(INITIAL_BRANCH_NAME), version_name)
+            .get_version_id(INITIAL_BRANCH_NAME, version_name)
             .map(|id| self.inner.version_exists(id))
             .unwrap_or(false)
     }
@@ -460,7 +460,7 @@ impl VsMgmt for MapxRawVs {
     /// Check if a version is directly created on the default branch.
     #[inline(always)]
     fn version_created(&self, version_name: VersionName) -> bool {
-        self.version_created_on_branch(version_name, BranchName(INITIAL_BRANCH_NAME))
+        self.version_created_on_branch(version_name, INITIAL_BRANCH_NAME)
     }
 
     /// Check if a version is directly created on a specified branch(exclude its parents).
@@ -560,6 +560,15 @@ impl VsMgmt for MapxRawVs {
             .unwrap_or(false)
     }
 
+    /// Check if a branch exists and has versions on it.
+    #[inline(always)]
+    fn branch_has_versions(&self, branch_name: BranchName) -> bool {
+        self.inner
+            .get_branch_id(branch_name)
+            .map(|id| self.inner.branch_has_versions(id))
+            .unwrap_or(false)
+    }
+
     /// Remove a branch, remove all changes directly made by this branch.
     ///
     /// 'Write'-like operations on branches and versions are different from operations on data.
